=================================
Flask IO
=================================
Flask IO is a library for Python 3+ which make easier to parse request arguments and serialize responses.

Documentation
===============
Soon... take a look at the example_ to see how it works.

Installation
===============
You can install Flask IO via Python Package Index (PyPi_),::

    $ pip install flask-io

Feedback
===============
Please use the Issues_ for feature requests and troubleshooting usage.

.. |Version| image:: https://badge.fury.io/py/flask-io.svg?
   :target: http://badge.fury.io/py/flask-io

.. |Downloads| image:: https://pypip.in/d/flask-io/badge.svg?
   :target: https://pypi.python.org/pypi/flask-io
   
.. |License| image:: https://pypip.in/license/flask-io/badge.svg?
   :target: https://github.com/viniciuschiele/flask-io/blob/master/LICENSE

.. _example: https://github.com/viniciuschiele/flask-io/tree/master/example

.. _PyPi: https://pypi.python.org/pypi/flask-io

.. _Issues: https://github.com/viniciuschiele/flask-io/issues
